@@ -378,7 +378,8 @@ void NmModelPrivate::onDeviceAdded(QString const & uni)
     NetworkManager::Device::Ptr dev = NetworkManager::findNetworkInterface(uni);
     if (!dev.isNull())
     {
-        Q_ASSERT(dev->isValid());
+        if (dev->isValid())
+            qCWarning(NM_TRAY).noquote() << Q_FUNC_INFO << uni << " is currently invalid...";
         emit deviceAdd(dev);
     }
 }
@@ -388,7 +389,8 @@ void NmModelPrivate::onDeviceRemoved(QString const & uni)
     NetworkManager::Device::Ptr dev = findDeviceUni(uni);
     if (!dev.isNull())
     {
-        Q_ASSERT(dev->isValid());
+        if (dev->isValid())
+            qCWarning(NM_TRAY).noquote() << Q_FUNC_INFO << uni << " is currently invalid...";
         emit deviceRemove(dev.data());
     }
 }
@@ -398,7 +400,8 @@ void NmModelPrivate::onActiveConnectionAdded(QString const & path)
     NetworkManager::ActiveConnection::Ptr conn = NetworkManager::findActiveConnection(path);//XXX: const QString &uni
     if (!conn.isNull())
     {
-        Q_ASSERT(conn->isValid());
+        if (conn->isValid())
+            qCWarning(NM_TRAY).noquote() << Q_FUNC_INFO << path << " is currently invalid...";
         emit activeConnectionAdd(conn);
     }
 }
@@ -408,7 +411,8 @@ void NmModelPrivate::onActiveConnectionRemoved(QString const & path)
     NetworkManager::ActiveConnection::Ptr conn = findActiveConnection(path);//XXX: const QString &uni
     if (!conn.isNull())
     {
-        Q_ASSERT(conn->isValid());
+        if (conn->isValid())
+            qCWarning(NM_TRAY).noquote() << Q_FUNC_INFO << path << " is currently invalid...";
         emit activeConnectionRemove(conn.data());
     }
 }
@@ -423,7 +427,8 @@ void NmModelPrivate::onConnectionAdded(QString const & path)
     NetworkManager::Connection::Ptr conn = NetworkManager::findConnection(path);
     if (!conn.isNull())
     {
-        Q_ASSERT(conn->isValid());
+        if (conn->isValid())
+            qCWarning(NM_TRAY).noquote() << Q_FUNC_INFO << path << " is currently invalid...";
         emit connectionAdd(conn);
     }
 }
@@ -433,7 +438,8 @@ void NmModelPrivate::onConnectionRemoved(QString const & path)
     NetworkManager::Connection::Ptr conn = NetworkManager::findConnection(path);
     if (!conn.isNull())
     {
-        Q_ASSERT(conn->isValid());
+        if (conn->isValid())
+            qCWarning(NM_TRAY).noquote() << Q_FUNC_INFO << path << " is currently invalid...";
         emit connectionRemove(conn.data());
     }
 }
@@ -1037,20 +1043,21 @@ QVariant NmModel::dataRole<NmModel::ActiveConnectionInfoRole>(const QModelIndex
                     hw_address = spec_dev->hwAddress();
                 }
                 break;
-            case NetworkManager::Device::Gre:
-                break;
             case NetworkManager::Device::Generic:
                 {
                     auto spec_dev = dev->as<NetworkManager::GenericDevice>();
                     hw_address = spec_dev->hardwareAddress();
                 }
                 break;
+            case NetworkManager::Device::Gre:
+                break;
             case NetworkManager::Device::InfiniBand:
                 {
                     auto spec_dev = dev->as<NetworkManager::InfinibandDevice>();
                     hw_address = spec_dev->hwAddress();
                 }
                 break;
+            case NetworkManager::Device::IpTunnel:
             case NetworkManager::Device::MacVlan:
             case NetworkManager::Device::Modem:
                 break;
@@ -1081,6 +1088,16 @@ QVariant NmModel::dataRole<NmModel::ActiveConnectionInfoRole>(const QModelIndex
                     hw_address = spec_dev->hwAddress();
                 }
                 break;
+            case NetworkManager::Device::Wimax:
+                //Wimax support was dropped in network manager 1.2.0
+                //we should never get here in runtime with nm >= 1.2.0
+                {
+                    auto spec_dev = dev->as<NetworkManager::WimaxDevice>();
+                    Q_ASSERT(nullptr != spec_dev);
+                    hw_address = spec_dev->hardwareAddress();
+                    //bit_rate = spec_dev->bitRate();
+                }
+                break;
             case NetworkManager::Device::Ethernet:
                 {
                     auto spec_dev = dev->as<NetworkManager::WiredDevice>();
@@ -1104,21 +1121,15 @@ QVariant NmModel::dataRole<NmModel::ActiveConnectionInfoRole>(const QModelIndex
                     }
                 }
                 break;
-            case NetworkManager::Device::Wimax:
-                //Wimax support was dropped in network manager 1.2.0
-                //we should never get here in runtime with nm >= 1.2.0
-                {
-                    auto spec_dev = dev->as<NetworkManager::WimaxDevice>();
-                    Q_ASSERT(nullptr != spec_dev);
-                    hw_address = spec_dev->hardwareAddress();
-                    //bit_rate = spec_dev->bitRate();
-                }
-                break;
             case NetworkManager::Device::UnknownType:
             case NetworkManager::Device::Unused1:
             case NetworkManager::Device::Unused2:
                 break;
-
+            case NetworkManager::Device::VxLan:
+            case NetworkManager::Device::MacSec:
+            case NetworkManager::Device::Dummy:
+                // Note: these devices are still not implemented in networkmanager-qt (as of v5.44.0)
+                break;
         }
         str << QStringLiteral("<table>")
             << QStringLiteral("<tr><td colspan='2'><big><strong>") << NmModel::tr("General", "Active connection information") << QStringLiteral("</strong></big></td></tr>")
@@ -1221,6 +1232,7 @@ QVariant NmModel::dataRole<NmModel::IconTypeRole>(const QModelIndex & index) con
                         return NetworkManager::ActiveConnection::Activated == state ? icons::NETWORK_WIRED : icons::NETWORK_WIRED_DISCONNECTED;
                 }
             }
+            break;
         case ITEM_WIFINET_LEAF:
             return icons::wifiSignalIcon(d->mWifiNets[index.row()]->signalStrength());
     }
